===============================
Office 365 Address Lists
===============================


.. image:: https://img.shields.io/pypi/v/oal.svg
        :target: https://pypi.python.org/pypi/oal

.. image:: https://img.shields.io/travis/napalm255/oal.svg
        :target: https://travis-ci.org/napalm255/oal

.. image:: https://readthedocs.org/projects/oal/badge/?version=latest
        :target: https://oal.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/napalm255/oal/shield.svg
     :target: https://pyup.io/repos/github/napalm255/oal/
     :alt: Updates


Office 365 Address Lists


* Free software: BSD license
* Documentation: https://oal.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `napalm255/cookiecutter-pymodule`_ project template.

.. _Cookiecutter: https://github.com/napalm255/cookiecutter
.. _`napalm255/cookiecutter-pymodule`: https://github.com/napalm255/cookiecutter-pymodule

